summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:11 -0600
commit0b46312b4c5d893a6e0c29e354038bbdc5a15fdd (patch)
tree0a9819d1f6fa2690e0819c97e4bcb9a87f0d397b
parent6981c239dedc72969f6f539afeef646a19c867c0 (diff)
downloadkima-0b46312b.tar.gz
kima-0b46312b.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 6981c239dedc72969f6f539afeef646a19c867c0.
-rw-r--r--src/flowlayout.cpp50
-rw-r--r--src/flowlayout.h10
-rw-r--r--src/kima.cpp10
-rw-r--r--src/kima.h2
-rw-r--r--src/prefs.cpp4
-rw-r--r--src/sources/acpithermalsrc.cpp2
-rw-r--r--src/sources/cpuinfofreqsrc.cpp2
-rw-r--r--src/sources/hddtempsrc.cpp2
-rw-r--r--src/sources/hwmonfansrc.cpp4
-rw-r--r--src/sources/hwmonthermalsrc.cpp4
-rw-r--r--src/sources/i8ksrc.cpp2
-rw-r--r--src/sources/ibmacpifansrc.cpp2
-rw-r--r--src/sources/ibmacpithermalsrc.cpp2
-rw-r--r--src/sources/ibmhdaps.cpp2
-rw-r--r--src/sources/ibookg4thermalsrc.cpp2
-rw-r--r--src/sources/labelsource.cpp8
-rw-r--r--src/sources/labelsourcePrefs.cpp32
-rw-r--r--src/sources/labelsourcePrefs.ui10
-rw-r--r--src/sources/omnibookthermalsrc.cpp2
-rw-r--r--src/sources/source.cpp6
-rw-r--r--src/sources/source.h10
-rw-r--r--src/sources/sourceprefs.cpp4
-rw-r--r--src/sources/sourceprefs.ui4
-rw-r--r--src/sources/sysfreqsrc.cpp2
-rw-r--r--src/sources/uptimesrc.cpp6
25 files changed, 92 insertions, 92 deletions
diff --git a/src/flowlayout.h b/src/flowlayout.h
index ae07a66..624d38b 100644
--- a/src/flowlayout.h
+++ b/src/flowlayout.h
@@ -20,7 +20,7 @@
#ifndef FLOWLAYOUT_H
#define FLOWLAYOUT_H
-#include <layout.h>
+#include <tqlayout.h>
#include <tqptrlist.h>
class Source;
@@ -49,7 +49,7 @@ public:
void addSource(Source* src);
void remove(TQWidget* widget);
/**
- * Returns the number of items in the layout
+ * Returns the number of items in the tqlayout
*/
uint count();
/**
@@ -62,8 +62,8 @@ public:
int heightForWidth(int w) const;
bool hasWidthForHeight() const;
int widthForHeight(int h) const;
- TQSize sizeHint() const;
- TQSize minimumSize() const;
+ TQSize tqsizeHint() const;
+ TQSize tqminimumSize() const;
TQLayoutIterator iterator();
TQSizePolicy::ExpandData expanding() const;
Qt::Orientation getOrientation() const;
@@ -84,7 +84,7 @@ private:
int doLayoutVertical( const TQRect&, bool testOnly );
Qt::Orientation mOrientation;
TQPtrList<TQLayoutItem> mLayoutItems;
- // this is the connection between a layout item and its source.
+ // this is the connection between a tqlayout item and its source.
TQMap<TQLayoutItem*, Source*> mSources;
TQLayoutItem* mLastItem; // the item that was last added
};
diff --git a/src/kima.cpp b/src/kima.cpp
index f0c49cc..eb30f5d 100644
--- a/src/kima.cpp
+++ b/src/kima.cpp
@@ -25,7 +25,7 @@
#include <tqfile.h>
#include <tqspinbox.h>
#include <tqcombobox.h>
-#include <textedit.h>
+#include <tqtextedit.h>
#include <tqtimer.h>
#include <tqcursor.h>
#include <klistview.h>
@@ -99,7 +99,7 @@ Kima::Kima(const TQString& inConfigFile, Type inType, int inActions, TQWidget* i
// automatically delete pointers
mSources.setAutoDelete(TRUE);
- // create layout
+ // create tqlayout
mLayout = new FlowLayout(this, orientation() );
mLayout->setSpacing(8);
@@ -319,7 +319,7 @@ int Kima::heightForWidth(int inWidth) const{
//kdDebug() << "heightForWidth: " << width << endl;
mLayout->setOrientation(Qt::Vertical);
return mLayout->heightForWidth(inWidth);
- //return sizeHint().height();
+ //return tqsizeHint().height();
}
void Kima::mousePressEvent(TQMouseEvent* inEvent ){
@@ -389,7 +389,7 @@ void Kima::paintEvent(TQPaintEvent* inEvent){
}
void Kima::updateSourceWidgets(){
- // repaint the source widgets
+ // tqrepaint the source widgets
for(Source* source = mSources.first(); source; source = mSources.next())
if(source->showOnApplet())
source->getWidget()->update();
@@ -406,7 +406,7 @@ void Kima::registerSource(Source* source) {
// this call also emits enabledChanged
source->loadPrefs(mKConfig);
- // add the source to the layout if necessary
+ // add the source to the tqlayout if necessary
displaySource(source->isEnabled() && source->showOnApplet(), source);
// connection to add and remove sources from mLayout
diff --git a/src/kima.h b/src/kima.h
index 024af95..8560799 100644
--- a/src/kima.h
+++ b/src/kima.h
@@ -155,7 +155,7 @@ public slots:
void raiseSourcePrefsWidget(TQListViewItem* inListViewItem);
/**
- * adds or removes the given source from the display (layout) of the kicker applet
+ * adds or removes the given source from the display (tqlayout) of the kicker applet
*/
void displaySource(bool inDisplay, Source* inSource);
diff --git a/src/prefs.cpp b/src/prefs.cpp
index 593cd58..5e5ba4a 100644
--- a/src/prefs.cpp
+++ b/src/prefs.cpp
@@ -16,7 +16,7 @@
#include <tqheader.h>
#include <klistview.h>
#include <tqwidgetstack.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqwhatsthis.h>
@@ -46,7 +46,7 @@ Prefs::Prefs( TQWidget* parent, const char* name, WFlags fl )
widgetStack->addWidget( WStackPage, 0 );
PrefsLayout->addWidget( splitter3 );
languageChange();
- resize( TQSize(340, 73).expandedTo(minimumSizeHint()) );
+ resize( TQSize(340, 73).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
diff --git a/src/sources/acpithermalsrc.cpp b/src/sources/acpithermalsrc.cpp
index 054c0e0..f762d00 100644
--- a/src/sources/acpithermalsrc.cpp
+++ b/src/sources/acpithermalsrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "acpithermalsrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdir.h>
#include <klocale.h>
diff --git a/src/sources/cpuinfofreqsrc.cpp b/src/sources/cpuinfofreqsrc.cpp
index c7b863f..6b1b55d 100644
--- a/src/sources/cpuinfofreqsrc.cpp
+++ b/src/sources/cpuinfofreqsrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "cpuinfofreqsrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqfile.h>
#include <klocale.h>
diff --git a/src/sources/hddtempsrc.cpp b/src/sources/hddtempsrc.cpp
index 34995d5..b22a6c8 100644
--- a/src/sources/hddtempsrc.cpp
+++ b/src/sources/hddtempsrc.cpp
@@ -38,7 +38,7 @@ HDDTempSrc::HDDTempSrc(TQWidget* inParent, uint inIndex, const TQString& inDevic
mTrigger(this){
mID = "HDDTemp" + TQString().setNum(inIndex);
mName = mID;
- mDescription = i18n("This source is provided by hddtemp. (%1, %2)").arg(inDevice).arg(inModelName);
+ mDescription = i18n("This source is provided by hddtemp. (%1, %2)").tqarg(inDevice).tqarg(inModelName);
}
HDDTempSrc::~HDDTempSrc(){
diff --git a/src/sources/hwmonfansrc.cpp b/src/sources/hwmonfansrc.cpp
index 6674111..17f57ae 100644
--- a/src/sources/hwmonfansrc.cpp
+++ b/src/sources/hwmonfansrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "hwmonfansrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdir.h>
#include <klocale.h>
@@ -30,7 +30,7 @@ HwMonFanSrc::HwMonFanSrc(TQWidget* inParent, const TQFile& inSourceFile, unsigne
//mName = "HwMon " + inSourceFile.name()[inSourceFile.name().length() - 7];
mID = "hwmonFan" + TQString::number(inIndex);
mName = mID;
- mDescription = i18n("This fan source is provided by hwmon. (%1)").arg(inSourceFile.name());
+ mDescription = i18n("This fan source is provided by hwmon. (%1)").tqarg(inSourceFile.name());
}
HwMonFanSrc::~HwMonFanSrc(){
diff --git a/src/sources/hwmonthermalsrc.cpp b/src/sources/hwmonthermalsrc.cpp
index d244d88..96af141 100644
--- a/src/sources/hwmonthermalsrc.cpp
+++ b/src/sources/hwmonthermalsrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "hwmonthermalsrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdir.h>
#include <klocale.h>
@@ -30,7 +30,7 @@ HwMonThermalSrc::HwMonThermalSrc(TQWidget* inParent, const TQFile& inSourceFile,
//mName = "HwMon " + inSourceFile.name()[inSourceFile.name().length() - 7];
mID = "hwmon" + TQString::number(inIndex);
mName = mID;
- mDescription = i18n("This thermal source is provided by hwmon. (%1)").arg(inSourceFile.name());
+ mDescription = i18n("This thermal source is provided by hwmon. (%1)").tqarg(inSourceFile.name());
}
HwMonThermalSrc::~HwMonThermalSrc(){
diff --git a/src/sources/i8ksrc.cpp b/src/sources/i8ksrc.cpp
index 235c665..50c1bf5 100644
--- a/src/sources/i8ksrc.cpp
+++ b/src/sources/i8ksrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "i8ksrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdir.h>
#include <klocale.h>
diff --git a/src/sources/ibmacpifansrc.cpp b/src/sources/ibmacpifansrc.cpp
index 8b517a8..a311bda 100644
--- a/src/sources/ibmacpifansrc.cpp
+++ b/src/sources/ibmacpifansrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "ibmacpifansrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqfile.h>
#include <klocale.h>
diff --git a/src/sources/ibmacpithermalsrc.cpp b/src/sources/ibmacpithermalsrc.cpp
index ba18019..770c885 100644
--- a/src/sources/ibmacpithermalsrc.cpp
+++ b/src/sources/ibmacpithermalsrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "ibmacpithermalsrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqfile.h>
#include <klocale.h>
//#include "hal/libhal.h"
diff --git a/src/sources/ibmhdaps.cpp b/src/sources/ibmhdaps.cpp
index a748c61..64d3d9a 100644
--- a/src/sources/ibmhdaps.cpp
+++ b/src/sources/ibmhdaps.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "ibmhdaps.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdir.h>
#include <klocale.h>
diff --git a/src/sources/ibookg4thermalsrc.cpp b/src/sources/ibookg4thermalsrc.cpp
index f9bbdaa..54f5a91 100644
--- a/src/sources/ibookg4thermalsrc.cpp
+++ b/src/sources/ibookg4thermalsrc.cpp
@@ -20,7 +20,7 @@
***************************************************************************/
#include "ibookg4thermalsrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <klocale.h>
IbookG4ThermalSrc::IbookG4ThermalSrc(TQWidget* inParent, const TQFile& inSourceFile, const TQString& inName):
diff --git a/src/sources/labelsource.cpp b/src/sources/labelsource.cpp
index ef98492..d4d2182 100644
--- a/src/sources/labelsource.cpp
+++ b/src/sources/labelsource.cpp
@@ -60,7 +60,7 @@ void LabelSource::updatePrefsGUI(){
TriggeredSource::updatePrefsGUI(); // update prefs of the super class
mLabelSourcePrefs->colorButton->setColor(mLabel->paletteForegroundColor());
mLabelSourcePrefs->fontRequester->setFont(mLabel->font());
- switch (mLabel->alignment()) {
+ switch (mLabel->tqalignment()) {
case TQt::AlignCenter:
mLabelSourcePrefs->alignmentComboBox->setCurrentItem(1);
break;
@@ -95,7 +95,7 @@ void LabelSource::applyPrefs(){
}else if(alignID == 2){
align = TQt::AlignRight;
}
- mLabel->setAlignment(align);
+ mLabel->tqsetAlignment(align);
updateLabel(mValue);
}
@@ -103,7 +103,7 @@ void LabelSource::savePrefs(KConfig* inKConfig){
TriggeredSource::savePrefs(inKConfig);
inKConfig->writeEntry(mID + "_color", mLabelSourcePrefs->colorButton->color());
inKConfig->writeEntry(mID + "_font", mLabelSourcePrefs->fontRequester->font());
- inKConfig->writeEntry(mID + "_align", mLabel->alignment());
+ inKConfig->writeEntry(mID + "_align", mLabel->tqalignment());
}
void LabelSource::loadPrefs(KConfig* inKConfig){
@@ -113,7 +113,7 @@ void LabelSource::loadPrefs(KConfig* inKConfig){
color.setRgb(0,0,0);
mLabel->setPaletteForegroundColor(color);
mLabel->setFont(inKConfig->readFontEntry(mID + "_font"));
- mLabel->setAlignment(inKConfig->readNumEntry(mID + "_align"));
+ mLabel->tqsetAlignment(inKConfig->readNumEntry(mID + "_align"));
}
void LabelSource::updateLabel(const TQString& inValue){
diff --git a/src/sources/labelsourcePrefs.cpp b/src/sources/labelsourcePrefs.cpp
index 99a8470..db9b675 100644
--- a/src/sources/labelsourcePrefs.cpp
+++ b/src/sources/labelsourcePrefs.cpp
@@ -18,7 +18,7 @@
#include <kcolorbutton.h>
#include <kfontrequester.h>
#include <tqcombobox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqwhatsthis.h>
@@ -44,39 +44,39 @@ LabelSourcePrefs::LabelSourcePrefs( TQWidget* parent, const char* name, WFlags f
taskbartitleLabel->setFont( taskbartitleLabel_font );
defaultSourcePrefsFrameLayout->addWidget( taskbartitleLabel );
- layout13 = new TQHBoxLayout( 0, 0, 6, "layout13");
+ tqlayout13 = new TQHBoxLayout( 0, 0, 6, "tqlayout13");
colorLabel = new TQLabel( defaultSourcePrefsFrame, "colorLabel" );
- layout13->addWidget( colorLabel );
+ tqlayout13->addWidget( colorLabel );
colorButton = new KColorButton( defaultSourcePrefsFrame, "colorButton" );
- layout13->addWidget( colorButton );
+ tqlayout13->addWidget( colorButton );
spacer1 = new TQSpacerItem( 350, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
- layout13->addItem( spacer1 );
- defaultSourcePrefsFrameLayout->addLayout( layout13 );
+ tqlayout13->addItem( spacer1 );
+ defaultSourcePrefsFrameLayout->addLayout( tqlayout13 );
- layout17 = new TQHBoxLayout( 0, 0, 6, "layout17");
+ tqlayout17 = new TQHBoxLayout( 0, 0, 6, "tqlayout17");
fontLabel = new TQLabel( defaultSourcePrefsFrame, "fontLabel" );
- layout17->addWidget( fontLabel );
+ tqlayout17->addWidget( fontLabel );
fontRequester = new KFontRequester( defaultSourcePrefsFrame, "fontRequester" );
- layout17->addWidget( fontRequester );
- defaultSourcePrefsFrameLayout->addLayout( layout17 );
+ tqlayout17->addWidget( fontRequester );
+ defaultSourcePrefsFrameLayout->addLayout( tqlayout17 );
- layout18 = new TQHBoxLayout( 0, 0, 6, "layout18");
+ tqlayout18 = new TQHBoxLayout( 0, 0, 6, "tqlayout18");
alignmentLabel = new TQLabel( defaultSourcePrefsFrame, "alignmentLabel" );
- layout18->addWidget( alignmentLabel );
+ tqlayout18->addWidget( alignmentLabel );
alignmentComboBox = new TQComboBox( FALSE, defaultSourcePrefsFrame, "alignmentComboBox" );
- layout18->addWidget( alignmentComboBox );
+ tqlayout18->addWidget( alignmentComboBox );
spacer2 = new TQSpacerItem( 350, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
- layout18->addItem( spacer2 );
- defaultSourcePrefsFrameLayout->addLayout( layout18 );
+ tqlayout18->addItem( spacer2 );
+ defaultSourcePrefsFrameLayout->addLayout( tqlayout18 );
LabelSourcePrefsLayout->addWidget( defaultSourcePrefsFrame );
languageChange();
- resize( TQSize(299, 135).expandedTo(minimumSizeHint()) );
+ resize( TQSize(299, 135).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
diff --git a/src/sources/labelsourcePrefs.ui b/src/sources/labelsourcePrefs.ui
index 2458413..a7f49db 100644
--- a/src/sources/labelsourcePrefs.ui
+++ b/src/sources/labelsourcePrefs.ui
@@ -55,7 +55,7 @@ Taskbar visual settings</string>
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout13</cstring>
+ <cstring>tqlayout13</cstring>
</property>
<hbox>
<property name="name">
@@ -87,7 +87,7 @@ Taskbar visual settings</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>350</width>
<height>20</height>
@@ -98,7 +98,7 @@ Taskbar visual settings</string>
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout17</cstring>
+ <cstring>tqlayout17</cstring>
</property>
<hbox>
<property name="name">
@@ -121,7 +121,7 @@ Taskbar visual settings</string>
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout18</cstring>
+ <cstring>tqlayout18</cstring>
</property>
<hbox>
<property name="name">
@@ -165,7 +165,7 @@ Taskbar visual settings</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>350</width>
<height>20</height>
diff --git a/src/sources/omnibookthermalsrc.cpp b/src/sources/omnibookthermalsrc.cpp
index ea91f95..11f8cd9 100644
--- a/src/sources/omnibookthermalsrc.cpp
+++ b/src/sources/omnibookthermalsrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "omnibookthermalsrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqfile.h>
#include <klocale.h>
diff --git a/src/sources/source.cpp b/src/sources/source.cpp
index 8ba4376..20885b0 100644
--- a/src/sources/source.cpp
+++ b/src/sources/source.cpp
@@ -20,7 +20,7 @@
#include "source.h"
#include <math.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlineedit.h>
#include <tqcheckbox.h>
#include <tqlabel.h>
@@ -107,7 +107,7 @@ TQWidget* Source::createPrefs(TQWidget* inParent){
createSubPrefs(mSourcePrefs);
// add bottom vspacer
- mSourcePrefs->layout()->addItem(new TQSpacerItem(0, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding) );
+ mSourcePrefs->tqlayout()->addItem(new TQSpacerItem(0, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding) );
updatePrefsGUI(); // fill the prefs gui
}
@@ -140,7 +140,7 @@ void Source::setPrefsWidgetsEnabled(bool isEnabled, bool isShownOnApplet){
void Source::addPrefs(TQWidget* inParent){
if(inParent != NULL)
- mSourcePrefs->layout()->add(inParent);
+ mSourcePrefs->tqlayout()->add(inParent);
}
void Source::applyPrefs(){
diff --git a/src/sources/source.h b/src/sources/source.h
index ff01049..6ae53c5 100644
--- a/src/sources/source.h
+++ b/src/sources/source.h
@@ -48,12 +48,12 @@ public:
const TQString& getID() const;
/**
- * Returns the position of this source in the layout
+ * Returns the position of this source in the tqlayout
*/
int getPosition() const;
/**
- * Sets the position of this source in the layout
+ * Sets the position of this source in the tqlayout
*/
void setPosition(int inPosition, KConfig* inKConfig);
@@ -145,9 +145,9 @@ signals:
/**
* This signal is emitted whenever the enabled flag (mEnabled) of this source has changed
*/
- void enabledChanged(bool inEnabled, Source* inSource); // needed by kima.cpp to add sources to its layout
+ void enabledChanged(bool inEnabled, Source* inSource); // needed by kima.cpp to add sources to its tqlayout
/**
- * This signal is emitted whenever this Source should be added or removed from the display (layout) of the kicker applet
+ * This signal is emitted whenever this Source should be added or removed from the display (tqlayout) of the kicker applet
*/
void displaySource(bool inDisplay, Source* inSource);
@@ -179,7 +179,7 @@ protected:
*/
TQString mID;
/**
- * The Position of the source in the layout
+ * The Position of the source in the tqlayout
*/
int mPosition;
/**
diff --git a/src/sources/sourceprefs.cpp b/src/sources/sourceprefs.cpp
index 4fbd5a7..160cfd0 100644
--- a/src/sources/sourceprefs.cpp
+++ b/src/sources/sourceprefs.cpp
@@ -16,7 +16,7 @@
#include <tqlabel.h>
#include <tqlineedit.h>
#include <tqcheckbox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqwhatsthis.h>
@@ -59,7 +59,7 @@ SourcePrefs::SourcePrefs( TQWidget* parent, const char* name, WFlags fl )
tooltipCheckBox = new TQCheckBox( this, "tooltipCheckBox" );
SourcePrefsLayout->addWidget( tooltipCheckBox );
languageChange();
- resize( TQSize(203, 127).expandedTo(minimumSizeHint()) );
+ resize( TQSize(203, 127).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
diff --git a/src/sources/sourceprefs.ui b/src/sources/sourceprefs.ui
index 46c3b8e..e063d39 100644
--- a/src/sources/sourceprefs.ui
+++ b/src/sources/sourceprefs.ui
@@ -61,7 +61,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -96,7 +96,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/src/sources/sysfreqsrc.cpp b/src/sources/sysfreqsrc.cpp
index 26e57c5..a90c127 100644
--- a/src/sources/sysfreqsrc.cpp
+++ b/src/sources/sysfreqsrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "sysfreqsrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqfile.h>
#include <tqdir.h>
#include <klocale.h>
diff --git a/src/sources/uptimesrc.cpp b/src/sources/uptimesrc.cpp
index a43ce92..cc9d0b5 100644
--- a/src/sources/uptimesrc.cpp
+++ b/src/sources/uptimesrc.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "uptimesrc.h"
-#include <textstream.h>
+#include <tqtextstream.h>
#include <klocale.h>
UptimeSrc::UptimeSrc(TQWidget* inParent, const TQFile& inSourceFile):
@@ -55,9 +55,9 @@ TQString UptimeSrc::fetchValue(){
TQString hours = TQString::number(secs / 3600 % 24).rightJustify(2, '0');
TQString days = TQString::number(secs / 86400);
if(days != "0")
- s = mTimeFormatLong.arg(days).arg(hours).arg(minutes);
+ s = mTimeFormatLong.tqarg(days).tqarg(hours).tqarg(minutes);
else
- s = mTimeFormatShort.arg(hours).arg(minutes);
+ s = mTimeFormatShort.tqarg(hours).tqarg(minutes);
mSourceFile.close();
}
return s;
diff --git a/src/flowlayout.cpp b/src/flowlayout.cpp
index 13490cf..7f10faf 100644
--- a/src/flowlayout.cpp
+++ b/src/flowlayout.cpp
@@ -156,7 +156,7 @@ bool FlowLayout::moveItem(const TQLayoutItem* which, const TQLayoutItem* relate,
newPos += direction;
// actually reinsert the item
mLayoutItems.insert(newPos, which);
- activate(); // relayout
+ activate(); // retqlayout
// kdDebug() << "oldPos: " << oldPos << ", newPos: " << newPos << endl;
return true;
}
@@ -181,25 +181,25 @@ bool FlowLayout::hasWidthForHeight() const{
return mOrientation == Qt::Horizontal;
}
-TQSize FlowLayout::sizeHint() const{
- //return minimumSize();
+TQSize FlowLayout::tqsizeHint() const{
+ //return tqminimumSize();
TQSize size(0,0);
TQPtrListIterator<TQLayoutItem> it(mLayoutItems);
TQLayoutItem *o;
while((o=it.current()) != 0){
++it;
- size = size.expandedTo( o->sizeHint() );
+ size = size.expandedTo( o->tqsizeHint() );
}
return size;
}
-TQSize FlowLayout::minimumSize() const{
+TQSize FlowLayout::tqminimumSize() const{
TQSize size(0,0);
TQPtrListIterator<TQLayoutItem> it(mLayoutItems);
TQLayoutItem *o;
while((o=it.current()) != 0){
++it;
- size = size.expandedTo(o->minimumSize());
+ size = size.expandedTo(o->tqminimumSize());
}
return size;
}
@@ -250,32 +250,32 @@ int FlowLayout::doLayoutHorizontal( const TQRect& rect, bool testOnly ){
TQPtrList<TQLayoutItem> column; // stores the items of one column
while((layoutItem = it.current()) != 0){
++it;
- //int nextY = y + layoutItem->sizeHint().height() + spacing(); // next y
- int nextY = y + layoutItem->sizeHint().height(); // next y
+ //int nextY = y + layoutItem->tqsizeHint().height() + spacing(); // next y
+ int nextY = y + layoutItem->tqsizeHint().height(); // next y
//if( nextY - spacing() > rect.bottom() && width > 0 ) {
if( nextY > rect.bottom() && width > 0 ) {
// next column
y = rect.y(); // reset y
x = x + width + spacing(); // new x
- //nextY = y + layoutItem->sizeHint().height() + spacing(); // next y with changed y
- nextY = y + layoutItem->sizeHint().height(); // next y with changed y
+ //nextY = y + layoutItem->tqsizeHint().height() + spacing(); // next y with changed y
+ nextY = y + layoutItem->tqsizeHint().height(); // next y with changed y
width = 0; // reset width for the next column
}
if(!testOnly){
- layoutItem->setGeometry( TQRect( TQPoint( x, y ), layoutItem->sizeHint() ) );
+ layoutItem->setGeometry( TQRect( TQPoint( x, y ), layoutItem->tqsizeHint() ) );
column.append(layoutItem);
- height += layoutItem->sizeHint().height(); // add the height of the current item to the column height
- if( it.current() == 0 || nextY + it.current()->sizeHint().height() > rect.bottom() ){ // test it it's the last item (of this column)
+ height += layoutItem->tqsizeHint().height(); // add the height of the current item to the column height
+ if( it.current() == 0 || nextY + it.current()->tqsizeHint().height() > rect.bottom() ){ // test it it's the last item (of this column)
// calculate real needed width
int rWidth = 0;
for(TQLayoutItem* item = column.first(); item; item = column.next()){
- rWidth = TQMAX( rWidth, item->widget()->sizeHint().width() );
+ rWidth = TQMAX( rWidth, item->widget()->tqsizeHint().width() );
}
- // relayout the items of the former column
+ // retqlayout the items of the former column
int space = (rect.height() - height) / (column.count() + 1);
int i = 0; // counts the items of this column
for(TQLayoutItem* item = column.first(); item; item = column.next()){
- TQRect r = item->geometry();
+ TQRect r = item->tqgeometry();
item->setGeometry( TQRect(r.left(), r.top() + ((++i) * space), rWidth, r.height()) );
}
column.clear(); // remove the items of the former column
@@ -283,7 +283,7 @@ int FlowLayout::doLayoutHorizontal( const TQRect& rect, bool testOnly ){
}
}
y = nextY;
- width = TQMAX( width, layoutItem->sizeHint().width() );
+ width = TQMAX( width, layoutItem->tqsizeHint().width() );
}
return x + width - rect.x(); // width
}
@@ -296,18 +296,18 @@ int FlowLayout::doLayoutVertical( const TQRect& rect, bool testOnly ){
TQLayoutItem* layoutItem;
while((layoutItem = it.current() ) != 0){
++it;
- //int nextX = x + layoutItem->sizeHint().width() + spacing();
- int nextX = x + layoutItem->sizeHint().width();
+ //int nextX = x + layoutItem->tqsizeHint().width() + spacing();
+ int nextX = x + layoutItem->tqsizeHint().width();
if(nextX - spacing() > rect.right() && height > 0) {
// next line
x = rect.x(); // reset x
//y = y + height + spacing(); // new y
y = y + height; // new y
- //nextX = x + layoutItem->sizeHint().width() + spacing(); // next x
- nextX = x + layoutItem->sizeHint().width(); // next x
+ //nextX = x + layoutItem->tqsizeHint().width() + spacing(); // next x
+ nextX = x + layoutItem->tqsizeHint().width(); // next x
height = 0; // reset height for the next line
}
- const int itemHeight = layoutItem->sizeHint().height();
+ const int itemHeight = layoutItem->tqsizeHint().height();
if(!testOnly)
layoutItem->setGeometry(TQRect(x, y, rect.right(), itemHeight));
x = nextX;
@@ -328,7 +328,7 @@ int FlowLayout::count() const {
\reimp
*/
TQLayoutItem* FlowLayout::itemAt(int index) const {
- return index >= 0 && index < mLayoutItems.count() ? (const_cast<TQPtrList<TQLayoutItem>&>(mLayoutItems).at(index)) : 0;
+ return index >= 0 && index < mLayoutItems.count() ? (const_cast<TQPtrList<TQLayoutItem>&>(mLayoutItems).tqat(index)) : 0;
}
/*!
@@ -337,8 +337,8 @@ TQLayoutItem* FlowLayout::itemAt(int index) const {
TQLayoutItem* FlowLayout::takeAt(int index) {
if (index < 0 || index >= mLayoutItems.count())
return 0;
- TQLayoutItem *item = mLayoutItems.at(index);
- mLayoutItems.remove(mLayoutItems.at(index));
+ TQLayoutItem *item = mLayoutItems.tqat(index);
+ mLayoutItems.remove(mLayoutItems.tqat(index));
delete item;
invalidate();